Slash
=====


|                       |                                                                                         |
|-----------------------|-----------------------------------------------------------------------------------------|
| Build Status          | ![Build Status](https://secure.travis-ci.org/getslash/slash.png?branch=master,dev)      |
| Supported Versions    | ![Supported Versions](https://img.shields.io/pypi/pyversions/slash.svg)                 |
| Latest Version        | ![Latest Version](https://img.shields.io/pypi/v/slash.svg)                              |
| Test Coverage         | ![Coverage Status](https://codecov.io/gh/getslash/slash/branch/develop/graph/badge.svg) |




Slash is a testing framework written in Python for testing complex projects. 

* [Homepage](http://getslash.github.io/slash)

* [Documentation](https://slash.readthedocs.org/)
